Diners Collage 1000 Piece Puzzle: 724819255917 | | Calendars.com
Description: This Diners 1000 Piece Jigsaw Puzzle by Lois Sutton takes us back in time to pay homage to blue plate specials, burgers and shakes, as well as pie a la mod

CALENDARS.COM
DOGBREEDSTORE.COM
🎄 Holiday Shipping Calendar
LOGIN
x
Confirm

Do you also want to Logout from Facebook?

*Selecting 'No' will keep you logged in to Facebook in this browser.

MY ACCOUNT
STORE LOCATOR
HELP
Popular Searches
0 ITEMS
$0.00
Items in your cart:
2016 beaches birds calendar towels calendar with pocket cars cats disney dogs flowers france geddes gifts halloween horse inspirational italy lang london magnetic calendars mary engelbreit minecraft national parks nature owl paris peanuts planners puzzle shoes star wars susan winget trains trees van gogh vintage wolves zen
2016 Calendars
Wall
Desk
Planners
|
Gifts
Games & Toys
Puzzles
On Sale
Diners Collage 1000 Piece Puzzle
By White Mountain Puzzles
ID : 201500014845

- Please select size

- Please select color

$14.99
In Stock

# Free Standard Shipping above $35

This Diners 1000 Piece Jigsaw Puzzle by Lois Sutton takes us back in time to pay homage to blue plate specials, burgers and shakes, as well as pie a la mode served with fresh hot coffee 24 hours a day.more

This Diners 1000 Piece Jigsaw Puzzle by Lois Sutton takes us back in time to pay homage to blue plate specials, burgers and shakes, as well as pie a la mode served with fresh hot coffee 24 hours a day.

- Full-color illustration by Lois Sutton
- Made of the finest quality, interlocking, premium blue chipboard
- Made in U.S.A.

ID:
201500014845
By:
White Mountain Puzzles
Dimensions:
12.0" x 10.0" x 2.0"
Finished Dimensions:
30" x 24"
Piece Count:
1000
MPN:
724819255917
Printable Reviews